tokenizer\_tools.tagset.converter package
=========================================

Submodules
----------

tokenizer\_tools.tagset.converter.offset\_to\_biluo module
----------------------------------------------------------

.. automodule:: tokenizer_tools.tagset.converter.offset_to_biluo
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: tokenizer_tools.tagset.converter
   :members:
   :undoc-members:
   :show-inheritance:
